Calculate Lagrangian correlation of the exponential form
.cor_lagr_exp(v1, v2, k = 2, h1, h2, u)Correlations of the same dimension as h1.
Prevailing wind, u-component.
Prevailing wind, v-component.
Scale parameter of \(\|\boldsymbol v\|\), \(k>0\). Default is 2.
Horizontal distance matrix or array.
Vertical distance matrix or array, same dimension as h1.
Time lag, same dimension as h1.
The Lagrangian correlation function of the exponential form with parameters \(\boldsymbol v = (v_1, v_2)^\top\in\mathbb{R}^2\) has the form $$C(\mathbf{h}, u)=\exp\left(-\dfrac{1}{k\|\boldsymbol v\|} \left\|\mathbf{h}-u\boldsymbol v\right\|\right),$$ where \(\|\cdot\|\) is the Euclidean distance, \(\mathbf{h} = (\mathrm{h}_1, \mathrm{h}_2)^\top\in\mathbb{R}^2\), and \(k > 0\) is the scale parameter controlling the magnitude of asymmetry in correlation.
Diggle, P. J., Tawn, J. A., & Moyeed, R. A. (1998). Model-Based Geostatistics. Journal of the Royal Statistical Society. Series C (Applied Statistics), 47(3), 299–350.