Simulate regime-switching Markov chain Gaussian field
.mcgf_rs_sim(
N,
label,
base_ls,
lagrangian_ls,
par_base_ls,
par_lagr_ls,
lambda_ls,
dists_ls,
sd_ls,
lag_ls,
scale_time = 1,
init = 0,
mu_c_ls,
mu_p_ls,
return_all = FALSE
)Simulated regime-switching Markov chain Gaussian field with
user-specified covariance structures. The simulation is done by kriging.
The output data is in space-wide format. Each element in dists_ls must
contain h for symmetric models, and h1 and h2 for general stationary
models. init can be a scalar or a vector of appropriate size.
List elements in sd_ls, mu_c_ls, and mu_p_ls must be vectors of
appropriate sizes.
Sample size.
Vector of regime labels of the same length as N.
List of base model, sep or fs for now.
List of Lagrangian model, "none" or lagr_tri for now.
List of parameters for the base model.
List of parameters for the Lagrangian model.
List of weight of the Lagrangian term, \(\lambda\in[0, 1]\).
List of distance matrices or arrays.
List of standard deviation for each location.
List of time lags.
Scale of time unit, default is 1. Elements in lag_ls are
divided by scale_time.
Initial samples, default is 0.
List of means of current and past.
Logical; if TRUE the joint covariance matrix, arrays of distances and time lag are returned.